@@ -720,6 +720,7 @@ pref("network.IDN.whitelist.sh", true);
 pref("network.IDN.whitelist.th", true);
 pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
+pref("network.IDN.whitelist.ua", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
@@ -728,6 +729,8 @@ pref("network.IDN.whitelist.xn--mgbaam7a8h", true);
 // cn, China, .<China> with variants
 pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
 pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// eg, Egypt, .<Masr>
+pref("network.IDN.whitelist.xn--wgbh1c", true);
 // hk, Hong Kong, .<Hong Kong>
 pref("network.IDN.whitelist.xn--j6w193g", true);
 // ir, Iran, <.Iran> with variants
@@ -834,7 +837,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 851 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 854 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -853,9 +856,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 871 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 874 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 878 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 881 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1217,15 +1220,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1618 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 1621 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2035 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2038 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2236 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
-
-//@line 2330 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2239 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 //@line 2333 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+
+//@line 2336 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1493,15 +1496,15 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2603 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2606 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2671 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2674 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2697 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2700 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2717 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2720 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2725 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2728 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1525,7 +1528,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2754 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2757 "/builds/slave/rel-comm-191-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
